"""Products module for handling Copernicus product data and metadata."""

from .products_manager import ProductMetadata, ProductQuicklook, ProductsManager

__all__ = ["ProductsManager", "ProductQuicklook", "ProductMetadata"]
